@@ -108,14 +108,6 @@ public:
      * Returns true if the node represents a random variable.
      */
     virtual bool isRandomVariable() const = 0;
-    /**
-     * Sets the value of the node, in all chains, and marks the node
-     * as observed. This function can only be called once for a given
-     * Node.
-     * 
-     * @param value vector of values
-     */
-    void setObserved(std::vector<double> const &value);
     /**
      * Indicates whether the node is observed. 
      */
