@@ -28,7 +28,8 @@ public:
     ~ParallelSampler();
     void update(std::vector<RNG*> const &rngs);
     bool isAdaptive() const;
-    bool adaptOff();
+    void adaptOff();
+    bool checkAdaptation() const;
     std::string name() const;
 };
 
