@@ -14,10 +14,9 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
- *  A copy of the GNU General Public License is available via WWW at
- *  http://www.gnu.org/copyleft/gpl.html.  You can also obtain it by
- *  writing to the Free Software Foundation, Inc.,
- *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, a copy is available at
+ *  http://www.r-project.org/Licenses/
  *
  *  SYNOPSIS
  *
@@ -54,9 +53,9 @@
 #include "dpq.h"
 /*----------- DEBUGGING -------------
  *	make CFLAGS='-DDEBUG_p -g -I/usr/local/include -I../include'
+ * (cd ~/R/D/r-devel/Linux-inst/src/nmath; gcc -std=gnu99 -I. -I../../src/include -I../../../R/src/include -I/usr/local/include -DDEBUG_p -g -O2 -c ../../../R/src/nmath/pgamma.c -o pgamma.o)
  */
 
-
 /* Scalefactor:= (2^32)^8 = 2^256 = 1.157921e+77 */
 #define SQR(x) ((x)*(x))
 static const double scalefactor = SQR(SQR(SQR(4294967296.0)));
@@ -125,16 +124,19 @@ double log1pmx (double x)
 
     if (x > 1 || x < minLog1Value)
 	return log1p(x) - x;
-    else { /* expand in	 [x/(2+x)]^2 */
-	double term = x / (2 + x);
-	double y = term * term;
+    else { /* -.791 <=  x <= 1  -- expand in  [x/(2+x)]^2 =: y :
+	    * log(1+x) - x =  x/(2+x) * [ 2 * y * S(y) - x],  with
+	    * ---------------------------------------------
+	    * S(y) = 1/3 + y/5 + y^2/7 + ... = \sum_{k=0}^\infty  y^k / (2k + 3)
+	   */
+	double r = x / (2 + x), y = r * r;
 	if (fabs(x) < 1e-2) {
 	    static const double two = 2;
-	    return term * ((((two / 9 * y + two / 7) * y + two / 5) * y +
+	    return r * ((((two / 9 * y + two / 7) * y + two / 5) * y +
 			    two / 3) * y - x);
 	} else {
 	    static const double tol_logcf = 1e-14;
-	    return term * (2 * y * logcf (y, 3, 2, tol_logcf) - x);
+	    return r * (2 * y * logcf (y, 3, 2, tol_logcf) - x);
 	}
     }
 }
@@ -198,8 +200,13 @@ double lgamma1p (double a)
     if (fabs (a) >= 0.5)
 	return lgammafn (a + 1);
 
-    /* Abramowitz & Stegun 6.1.33,
-     * also  http://functions.wolfram.com/06.11.06.0008.01 */
+    /* Abramowitz & Stegun 6.1.33 : for |x| < 2,
+     * <==> log(gamma(1+x)) = -(log(1+x) - x) - gamma*x + x^2 * \sum_{n=0}^\infty c_n (-x)^n
+     * where c_n := (Zeta(n+2) - 1)/(n+2)  = coeffs[n]
+     *
+     * Here, another convergence acceleration trick is used to compute
+     * lgam(x) :=  sum_{n=0..Inf} c_n (-x)^n
+     */
     lgam = c * logcf(-a / 2, N + 2, 1, tol_logcf);
     for (i = N - 1; i >= 0; i--)
 	lgam = coeffs[i] - a * lgam;
@@ -240,7 +247,7 @@ double logspace_sub (double logx, double logy)
 #ifndef R_USE_OLD_PGAMMA
 
 /* dpois_wrap (x_P_1,  lambda, g_log) ==
- *   dpois (x_P_1 - 1, lambda, g_log)
+ *   dpois (x_P_1 - 1, lambda, g_log) :=  exp(-L)  L^k / gamma(k+1) ,  k := x_P_1 - 1
 */
 static double
 dpois_wrap (double x_plus_1, double lambda, int give_log)
@@ -291,7 +298,7 @@ pgamma_smallx (double x, double alph, int lower_tail, int log_p)
     } while (fabs (term) > DBL_EPSILON * fabs (sum));
 
 #ifdef DEBUG_p
-    REprintf (" conv.sum=%g;", sum);
+    REprintf (" %d terms --> conv.sum=%g;", n, sum);
 #endif
     if (lower_tail) {
 	double f1 = log_p ? log1p (sum) : 1 + sum;
@@ -346,13 +353,13 @@ pd_upper_series (double x, double y, int log_p)
 
 /* Continued fraction for calculation of
  *    ???
- *  =  (i / d)	+  o(i/d)
+ *  =  (y / d)	+  o(y/d)
  */
 static double
-pd_lower_cf (double i, double d)
+pd_lower_cf (double y, double d)
 {
     double f = 0, of;
-    double c1, c2, c3, c4,  a1, b1,  a2, b2;
+    double i, c2, c3, c4,  a1, b1,  a2, b2;
 
 #define	NEEDED_SCALE				\
 	  (b2 > scalefactor) {			\
@@ -365,30 +372,38 @@ pd_lower_cf (double i, double d)
 #define max_it 200000
 
 #ifdef DEBUG_p
-    REprintf("pd_lower_cf(i=%.14g, d=%.14g)\n", i, d);
+    REprintf("pd_lower_cf(y=%.14g, d=%.14g)", y, d);
 #endif
+    if (y == 0 || (R_FINITE(y) && !R_FINITE(d))) /* includes d = Inf  or y = 0 */
+	return 0;
+    /* Needed, e.g. for  pgamma(10^c(100,295), shape= 1.1, log=TRUE) */
+    if(fabs(y - 1) < fabs(d) * 1e-20) {
+#ifdef DEBUG_p
+	REprintf(" very small 'y' -> returning (y/d)\n");
+#endif
+	return (y/d);
+    }
 
-    if (i < d * 1e-20) /* includes d = Inf,  or i = 0 < d */
-	return (i/d);
+    c2 = y;
+    c4 = d; /* original (y,d), *not* potentially scaled ones!*/
 
     a1 = 0; b1 = 1;
-    a2 = i; b2 = d;
+    a2 = y; b2 = d;
 
     while NEEDED_SCALE
 
-    if(a2 == 0) return 0;/* just in case, e.g. d=i=0 */
+    /* if(a2 == 0) return 0;/\* just in case, e.g. d=y=0 *\/ */
 
-    c2 = a2;
-    c4 = b2;
+    i = 0;
+    while (i < max_it) {
 
-    c1 = 0;
-    while (c1 < max_it) {
-
-	c1++;	c2--;	c3 = c1 * c2;	c4 += 2;
+	i++;	c2--;	c3 = i * c2;	c4 += 2;
+	/* c2 = y - i,  c3 = i(y - i),  c4 = d + 2i,  for i odd */
 	a1 = c4 * a2 + c3 * a1;
 	b1 = c4 * b2 + c3 * b1;
 
-	c1++;	c2--;	c3 = c1 * c2;	c4 += 2;
+	i++;	c2--;	c3 = i * c2;	c4 += 2;
+	/* c2 = y - i,  c3 = i(y - i),  c4 = d + 2i,  for i even */
 	a2 = c4 * a1 + c3 * a2;
 	b2 = c4 * b1 + c3 * b2;
 
@@ -397,13 +412,22 @@ pd_lower_cf (double i, double d)
 	if (b2 != 0) {
 	    of = f;
 	    f = a2 / b2;
+#ifdef UP_TO_2009_11_07__NO_LONGER
 	    /* convergence check: relative; absolute for small f : */
-	    if (fabs (f - of) <= DBL_EPSILON * fmax2(1., fabs(f)))
+	    if (fabs (f - of) <= DBL_EPSILON * fmax2(1., fabs(f))) { .. }
+#endif
+	    /* convergence check */
+	    if (fabs(f - of) <= DBL_EPSILON * fabs(f)) {
+#ifdef DEBUG_p
+		REprintf(" %g iter.\n", i);
+#endif
 		return f;
+	    }
 	}
     }
 
-    REprintf(" ** NON-convergence in pgamma()'s pd_lower_cf() f= %g.\n", f);
+    MATHLIB_WARNING(" ** NON-convergence in pgamma()'s pd_lower_cf() f= %g.\n",
+		    f);
     return f;/* should not happen ... */
 } /* pd_lower_cf() */
 #undef NEEDED_SCALE
@@ -423,7 +447,7 @@ pd_lower_series (double lambda, double y)
 	y--;
     }
     /* sum =  \sum_{n=0}^ oo  y*(y-1)*...*(y - n) / lambda^(n+1)
-     *	   =  y/lambda * (1 + \sum_{n=1}^Inf  (y-1)*...*(y-n) / lambda^n
+     *	   =  y/lambda * (1 + \sum_{n=1}^Inf  (y-1)*...*(y-n) / lambda^n)
      *	   ~  y/lambda + o(y/lambda)
      */
 #ifdef DEBUG_p
@@ -440,7 +464,7 @@ pd_lower_series (double lambda, double y)
 	REprintf(" y not int: add another term ");
 #endif
 	/* FIXME: in quite few cases, adding  term*f  has no effect (f too small)
-	 *	  and unnecessary e.g. for pgamma(4e12, 121.1) */
+	 *	  and is unnecessary e.g. for pgamma(4e12, 121.1) */
 	f = pd_lower_cf (y, lambda + 1 - y);
 #ifdef DEBUG_p
 	REprintf("  (= %.14g) * term = %.14g to sum %g\n", f, term * f, sum);
@@ -608,7 +632,7 @@ double pgamma_raw (double x, double alph, int lower_tail, int log_p)
 	double sum = pd_upper_series (x, alph, log_p);/* = x/alph + o(x/alph) */
 	double d = dpois_wrap (alph, x, log_p);
 #ifdef DEBUG_p
-	REprintf(" alph `large': sum=pd_upper*()= %.12g, d=dpois_w(*)= %.12g ",
+	REprintf(" alph 'large': sum=pd_upper*()= %.12g, d=dpois_w(*)= %.12g\n",
 		 sum, d);
 #endif
 	if (!lower_tail)
@@ -622,7 +646,7 @@ double pgamma_raw (double x, double alph, int lower_tail, int log_p)
 	double sum;
 	double d = dpois_wrap (alph, x, log_p);
 #ifdef DEBUG_p
-	REprintf(" x `large': d=dpois_w(*)= %.14g ", d);
+	REprintf(" x 'large': d=dpois_w(*)= %.14g ", d);
 #endif
 	if (alph < 1) {
 	    if (x * DBL_EPSILON > 1 - alph)
@@ -645,7 +669,7 @@ double pgamma_raw (double x, double alph, int lower_tail, int log_p)
 	    res = log_p
 		? R_Log1_Exp (d + sum)
 		: 1 - d * sum;
-    } else { /* x > 1 and x fairly near alph. */
+    } else { /* x >= 1 and x fairly near alph. */
 #ifdef DEBUG_p
 	REprintf(" using ppois_asymp()\n");
 #endif
@@ -674,13 +698,15 @@ double pgamma(double x, double alph, double scale, int lower_tail, int log_p)
     if (ISNAN(x) || ISNAN(alph) || ISNAN(scale))
 	return x + alph + scale;
 #endif
-    if(alph <= 0. || scale <= 0.)
+    if(alph < 0. || scale <= 0.)
 	ML_ERR_return_NAN;
     x /= scale;
 #ifdef IEEE_754
     if (ISNAN(x)) /* eg. original x = scale = +Inf */
 	return x;
 #endif
+    if(alph == 0.) /* limit case; useful e.g. in pnchisq() */
+	return (x < 0) ? R_DT_0: R_DT_1;
     return pgamma_raw (x, alph, lower_tail, log_p);
 }
 /* From: terra@gnome.org (Morten Welinder)
