@@ -1,7 +1,7 @@
 /*
  *  Mathlib : A C Library of Special Functions
  *  Copyright (C) 1998 Ross Ihaka
- *  Copyright (C) 2000 The R Development Core Team
+ *  Copyright (C) 2000--2008 The R Development Core Team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -14,8 +14,8 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ *  along with this program; if not, a copy is available at
+ *  http://www.r-project.org/Licenses/
  *
  *  SYNOPSIS
  *
@@ -32,8 +32,10 @@
 
 double rexp(double scale, RNG *rng)
 {
-    if (!R_FINITE(scale) || scale <= 0.0)
+    if (!R_FINITE(scale) || scale <= 0.0) {
+	if(scale == 0.) return 0.;
+	/* else */
 	ML_ERR_return_NAN;
-
+    }
     return scale * exp_rand(rng);
 }
