@@ -1,7 +1,7 @@
 /*
  *  Mathlib : A C Library of Special Functions
  *  Copyright (C) 1998 Ross Ihaka
- *  Copyright (C) 2000-2001 The R Development Core Team
+ *  Copyright (C) 2000-2008 The R Development Core Team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -14,8 +14,8 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ *  along with this program; if not, a copy is available at
+ *  http://www.r-project.org/Licenses/
  *
  *  DESCRIPTION
  *
@@ -28,17 +28,16 @@
 
 #include "nmath.h"
 
-double rt(double df, RNG* rng)
+double rt(double df, RNG *rng)
 {
-    double num;
     if (ISNAN(df) || df <= 0.0)	ML_ERR_return_NAN;
 
     if(!R_FINITE(df))
 	return norm_rand(rng);
     else {
 /* Some compilers (including MW6) evaluated this from right to left
-	return norm_rand() / sqrt(rchisq(df) / df); */
-	num = norm_rand(rng);
+	return norm_rand(rng) / sqrt(rchisq(df) / df); */
+	double num = norm_rand(rng);
 	return num / sqrt(rchisq(df, rng) / df);
     }
 }
