@@ -3,6 +3,7 @@
 
 #include <compiler/ParseTree.h>
 #include <cstdio>
+#include <string>
 
 /**
  * Parse a model file that describes the graphical model using the
@@ -16,7 +17,8 @@
  * pvariables will point to a newly allocated ParseTree representing
  * the stochastic and logical relationships between declared nodes.
  */
-int parse_bugs(std::FILE *file, std::vector<ParseTree*> **pvariables, 
-	       ParseTree **pdata, ParseTree **prelations);
+int parse_bugs(std::FILE *file, std::vector<ParseTree*> * &pvariables, 
+	       ParseTree * &pdata, ParseTree * &prelations,
+	       std::string &message);
 
 #endif /* PARSER_EXTRA_H_ */
