@@ -4,20 +4,20 @@
 #include <sstream>
 #include <cmath>
 #include <algorithm>
+#include <stdexcept>
 
 using std::vector;
 using std::string;
 using std::ostringstream;
 using std::floor;
 using std::copy;
+using std::logic_error;
 
 ConstantNode::ConstantNode(double value, unsigned int nchain)
   : Node(vector<unsigned int>(1,1), nchain)
 {
-    setObserved(vector<double>(1,value));
-    //FIXME: This should be done within the setObserved function
-    if (value == floor(value)) {
-	setDiscreteValued();
+    for (unsigned int n = 0; n < nchain; ++n) {
+       setValue(&value, 1, n);
     }
 }
 
@@ -26,7 +26,31 @@ ConstantNode::ConstantNode(vector<unsigned int> const &dim,
 			   unsigned int nchain)
     : Node(dim, nchain)
 {
-    setObserved(value);
+    if (value.size() != _length) {
+        throw logic_error("Invalid value in ConstantNode");
+    }
+
+    //FIXME: Should we be using an array in constructor anyway?
+    double *val = new double[_length];
+    copy(value.begin(), value.end(), val);
+    for (unsigned int n = 0; n < nchain; ++n) {
+       setValue(val, _length, n);
+    }
+    delete [] val;
+}
+
+ConstantNode::~ConstantNode()
+{
+}
+
+bool ConstantNode::isDiscreteValued() const
+{
+    double const *val = value(0);
+    for (unsigned int i = 0; i < _length; ++i) {
+        if (val[i] != floor(val[i]))
+            return false;
+    }
+    return true;
 }
 
 void ConstantNode::deterministicSample(unsigned int) {}
@@ -45,16 +69,6 @@ string ConstantNode::deparse(vector<string> const &parents) const
     return os.str();
 }
 
-bool ConstantNode::isLinear(GraphMarks const &linear_marks, bool fixed) const
-{
-    return true;
-}
-
-bool ConstantNode::isScale(GraphMarks const &scale_marks, bool fixed) const
-{
-    return true;
-}
-
 bool ConstantNode::checkParentValues(unsigned int) const
 {
     return true;
@@ -65,3 +79,7 @@ bool ConstantNode::isRandomVariable() const
     return true;
 }
 
+bool ConstantNode::isObserved() const
+{
+    return true;
+}
