@@ -7,7 +7,6 @@
 #include <functions/Equal.h>
 #include <functions/GreaterOrEqual.h>
 #include <functions/GreaterThan.h>
-#include <functions/IfElse.h>
 #include <functions/LessOrEqual.h>
 #include <functions/LessThan.h>
 #include <functions/Multiply.h>
@@ -24,6 +23,7 @@
 #include <rngs/BaseRNGFactory.h>
 //Monitors
 #include <monitors/TraceMonitorFactory.h>
+#include <monitors/MeanMonitorFactory.h>
 
 using std::vector;
 
@@ -46,7 +46,6 @@ namespace base {
 	insert(new Equal);
 	insert(new GreaterOrEqual);
 	insert(new GreaterThan);
-        insert(new IfElse);
 	insert(new LessOrEqual);
 	insert(new LessThan);
 	insert(new Multiply);
@@ -63,7 +62,7 @@ namespace base {
 	insert(new BaseRNGFactory);
 	
 	insert(new TraceMonitorFactory);
-
+	insert(new MeanMonitorFactory);
     }
 
     BaseModule::~BaseModule() {
