@@ -7,9 +7,8 @@ namespace base {
 
 /**
  * The Add function implements the infix operator "+" in the BUGS language.
- * The expression a + b + c is broken down into ((a + b) + c), so two
- * separate calls to Add are made.
- * @short Sum of two scalars
+ * The expression a + b + c is evaluated in a single function call.
+ * @short Sum of scalars
  * <pre>
  * y <- a + b
  * </pre>
@@ -18,10 +17,12 @@ class Add : public Infix
 {
 public:
     Add ();
-    double evaluateScalar(std::vector<double const *>const &args) const;
+    double evaluate(std::vector<double const *>const &args) const;
     bool isDiscreteValued(std::vector<bool> const &flags) const;
     bool isLinear(std::vector<bool> const &mask,
 		  std::vector<bool> const &fixmask) const;
+    bool isScale(std::vector<bool> const &mask,
+		 std::vector<bool> const &fixmask) const;
 };
 
 }
