@@ -14,7 +14,7 @@ double And::evaluate(vector <double const *> const &args) const
   return *args[0] && *args[1];
 }
 
-bool And::isDiscreteValued(std::vector<bool> const &mask) const
+bool And::isDiscreteValued(vector<bool> const &mask) const
 {
   return true;
 }
