@@ -17,7 +17,7 @@ double GreaterOrEqual::evaluate(vector<double const *> const &args) const
   return *args[0] >= *args[1];
 }
 
-bool GreaterOrEqual::isDiscreteValued(std::vector<bool> const &mask) const
+bool GreaterOrEqual::isDiscreteValued(vector<bool> const &mask) const
 {
   return true;
 }
