@@ -17,7 +17,7 @@ double GreaterThan::evaluate(vector<double const *> const &args) const
   return *args[0] > *args[1];
 }
 
-bool GreaterThan::isDiscreteValued(std::vector<bool> const &mask) const
+bool GreaterThan::isDiscreteValued(vector<bool> const &mask) const
 {
   return true;
 }
