@@ -18,10 +18,12 @@ class Subtract : public Infix
 { 
 public:
     Subtract ();
-    double evaluateScalar(std::vector<double const *> const &args) const;
+    double evaluate(std::vector<double const *> const &args) const;
     bool isDiscreteValued(std::vector<bool> const &mask) const;
+    bool isScale(std::vector<bool> const &mask, 
+		 std::vector<bool> const &fix) const;
     bool isLinear(std::vector<bool> const &mask, 
-		  std::vector<bool> const &fixmask) const;
+		  std::vector<bool> const &fix) const;
 };
 
 }
