@@ -48,6 +48,7 @@
 #include <functions/Exp.h>
 #include <functions/Equals.h>
 #include <functions/ICLogLog.h>
+#include <functions/IfElse.h>
 #include <functions/ILogit.h>
 #include <functions/InProd.h>
 #include <functions/InterpLin.h>
@@ -61,8 +62,8 @@
 #include <functions/Mean.h>
 #include <functions/Min.h>
 #include <functions/MatMult.h>
+#include <functions/Order.h>
 #include <functions/Phi.h>
-#include <functions/Pow.h>
 #include <functions/Probit.h>
 #include <functions/Prod.h>
 #include <functions/Rank.h>
@@ -146,6 +147,7 @@ namespace bugs {
 	insert(new Exp);
 	insert(new Equals);
 	insert(new ICLogLog);
+	insert(new IfElse);
 	insert(new ILogit);
 	insert(new InProd);
 	insert(new InterpLin);
@@ -159,8 +161,8 @@ namespace bugs {
 	insert(new Max);
 	insert(new Mean);
 	insert(new Min);
+	insert(new Order);
 	insert(new Phi);
-	insert(new Pow);
 	insert(new Probit);
 	insert(new Prod);
 	insert(new Rank);
