@@ -4,19 +4,16 @@
 #include <util/dim.h>
 #include <util/nainf.h>
 
-#include <stdexcept>
 #include <cmath>
 
 #include <JRmath.h>
 
 using std::vector;
-using std::length_error;
-using std::logic_error;
+using std::string;
 
 #define ALPHA(par) (par[0])
 #define LENGTH(len) (len[0])
 
-
 /* The Dirichlet distribution is extended to allow zero shape parameters.
    These represent structural zeros: when x ~ ddirch(alpha) is forward
    sampled, x[i] = 0 when alpha[i] = 0. To avoid trapping states in the
@@ -24,10 +21,17 @@ using std::logic_error;
    is fixed.
 */
 
+namespace bugs {
+
 DDirch::DDirch()
   : VectorDist("ddirch", 1) 
 {}
 
+string DDirch::alias() const
+{
+    return "ddirich";
+}
+
 unsigned int DDirch::length(vector<unsigned int> const &len) const
 {
     return LENGTH(len);
@@ -57,14 +61,13 @@ DDirch::checkParameterValue(vector<double const *> const &par,
     return has_nonzero_alpha;
 }
 
-double DDirch::logLikelihood(double const *x, unsigned int length,
-			     vector<double const *> const &par,
-                             vector<unsigned int> const &len,
-			     double const *lower, double const *upper) const
+double DDirch::logDensity(double const *x, unsigned int length, PDFType type,
+			  vector<double const *> const &par,
+			  vector<unsigned int> const &len,
+			  double const *lower, double const *upper) const
 {
     double const *alpha = ALPHA(par);
 
-    double alphasum = 0.0;
     double loglik = 0.0;
     for (unsigned int i = 0; i < length; i++) {
 	if (alpha[i] == 0) {
@@ -72,11 +75,21 @@ double DDirch::logLikelihood(double const *x, unsigned int length,
 		return JAGS_NEGINF;
 	}
 	else {
-	    alphasum += alpha[i];
-	    loglik += (alpha[i] - 1) * log(x[i]) - lgamma(alpha[i]);
+	    loglik += (alpha[i] - 1) * log(x[i]);
 	}
     }
-    loglik += lgamma(alphasum);
+
+    if (type != PDF_PRIOR) {
+	//Need to calculate normalizing constant
+	double alphasum = 0.0;
+	for (unsigned int i = 0; i < length; i++) {
+	    if (alpha[i] != 0) {
+		loglik -= lgammafn(alpha[i]);
+		alphasum += alpha[i];
+	    }
+	}
+	loglik += lgammafn(alphasum);
+    }
 
     return loglik;
 }
@@ -138,3 +151,37 @@ unsigned int DDirch::df(vector<unsigned int> const &len) const
 {
     return LENGTH(len) - 1;
 }
+
+double DDirch::KL(vector<double const *> const &par1,
+		  vector<double const *> const &par2,
+		  vector<unsigned int> const &len) const
+{
+    //Generalization of the Kullback-Leibler divergence for the beta
+    //distribution. We also have to take care of structural zeros as
+    //in DCat
+
+    unsigned int N = LENGTH(len);
+
+    double S1 = 0, S2 = 0, y = 0;
+    for (unsigned int i = 0; i < N; ++i) {
+	double a1 = ALPHA(par1)[i];
+	double a2 = ALPHA(par2)[i];
+
+	if (a1 == 0) {
+	    S2 += a2;
+	}
+	else if (a2 == 0) {
+	    return JAGS_POSINF;
+	}
+	else {
+	    y += (a1 - a2) * digamma(a1) + lgammafn(a2) - lgammafn(a1);
+	    S1 += a1;
+	    S2 += a2;
+	}
+    }
+    y -= (S1 - S2) * digamma(S1) + lgammafn(S2) - lgammafn(S1);
+
+    return y;
+}
+
+}
