@@ -2,6 +2,7 @@
 #include "DGamma.h"
 
 #include <JRmath.h>
+#include <util/nainf.h>
 
 using std::vector;
 
@@ -9,6 +10,8 @@ using std::vector;
 #define SCALE(par) (1 / *par[1])
 #define RATE(par) (*par[1])
 
+namespace bugs {
+
 DGamma::DGamma()
     : RScalarDist("dgamma", 2, DIST_POSITIVE)
 {}
@@ -20,10 +23,26 @@ DGamma::checkParameterValue (vector<double const *> const &par) const
 }
 
 double
-DGamma::d(double x, vector<double const *> const &par, bool give_log) 
-    const
+DGamma::d(double x, PDFType type,
+	  vector<double const *> const &par, bool give_log)  const
 {
-    return dgamma(x, SHAPE(par), SCALE(par), give_log);
+    if (type == PDF_PRIOR) {
+	//Avoid expensive evaluation of gamma function
+	if (x < 0) {
+	    return give_log ? JAGS_NEGINF : 0;
+	}
+	else if (x == 0) {
+	    //Density at zero defined by continuity
+	    return xlog0(SHAPE(par) - 1, give_log);
+	}
+	else {
+	    double y = (SHAPE(par) - 1) * log(x) - RATE(par) * x;
+	    return give_log ? y : exp(y);
+	}
+    }
+    else {
+	return dgamma(x, SHAPE(par), SCALE(par), give_log);
+    }
 }
 
 double
@@ -56,3 +75,13 @@ double DGamma::typicalValue(vector<double const *> const &par,
     }
 }
 
+double DGamma::KL(vector<double const *> const &par1,
+		  vector<double const *> const &par2) const
+{
+    double b1 = SHAPE(par1), b2 = SHAPE(par2); 
+    double r = RATE(par2) / RATE(par1);
+    return (r - 1) * b1  - b2 * log(r)
+	+ (b1 - b2) * digamma(b1) + lgammafn(b2) - lgammafn(b1);
+}
+
+}
