@@ -3,6 +3,8 @@
 
 #include "RScalarDist.h"
 
+namespace bugs {
+
 /**
  * @short Hypergeometric distribution
  * <pre>
@@ -13,7 +15,8 @@ class DHyper : public RScalarDist {
  public:
   DHyper();
 
-  double d(double x, std::vector<double const *> const &parameters, 
+  double d(double x, PDFType type,
+	   std::vector<double const *> const &parameters, 
 	   bool give_log) const;
   double p(double x, std::vector<double const *> const &parameters, bool lower,
 	   bool give_log) const;
@@ -29,6 +32,10 @@ class DHyper : public RScalarDist {
   bool checkParameterValue(std::vector<double const*> const &parameters) const;
   bool isSupportFixed(std::vector<bool> const &fixmask) const;
   bool canBound() const;
+  double KL(std::vector<double const *> const &par1,
+	    std::vector<double const *> const &par2) const;
 };
 
+}
+
 #endif /* DHYPER_H_ */
