@@ -3,6 +3,8 @@
 
 #include "RScalarDist.h"
 
+namespace bugs {
+
 /** 
  * @short Lognormal distribution
  * <pre>
@@ -14,7 +16,8 @@ class DLnorm : public RScalarDist {
  public:
   DLnorm();
 
-  double d(double x, std::vector<double const *> const &parameters, 
+  double d(double x, PDFType type,
+	   std::vector<double const *> const &parameters, 
 	   bool give_log) const;
   double p(double q, std::vector<double const *> const &parameters, bool lower,
 	   bool give_log) const;
@@ -25,7 +28,10 @@ class DLnorm : public RScalarDist {
    * Checks that tau > 0
    */
   bool checkParameterValue(std::vector<double const *> const &parameters) const;
-
+  double KL(std::vector<double const *> const &par0,
+	    std::vector<double const *> const &par1) const;
 };
 
+}
+
 #endif /* DLNORM_H_ */
