@@ -3,6 +3,8 @@
 
 #include "RScalarDist.h"
 
+namespace bugs {
+
 /** 
  * Logistic distribution
  * <pre>
@@ -14,7 +16,8 @@ class DLogis : public RScalarDist {
  public:
   DLogis();
 
-  double d(double x, std::vector<double const *> const &parameters, bool give_log) const;
+  double d(double x, PDFType type,
+	   std::vector<double const *> const &parameters, bool give_log) const;
   double p(double q, std::vector<double const *> const &parameters, bool lower,
 	   bool give_log) const;
   double q(double p, std::vector<double const *> const &parameters, bool lower,
@@ -26,4 +29,6 @@ class DLogis : public RScalarDist {
   bool checkParameterValue(std::vector<double const *> const &parameters) const;
 };
 
+}
+
 #endif /* DLOGIS_H_ */
