@@ -3,6 +3,8 @@
 
 #include "RScalarDist.h"
 
+namespace bugs {
+
 /**
  * <pre>
  * x ~ dnegbin(p, r)
@@ -13,8 +15,9 @@
 class DNegBin : public RScalarDist {
  public:
   DNegBin();
-
-  double d(double x, std::vector<double const *> const &parameters, 
+  std::string alias() const;
+  double d(double x, PDFType type,
+	   std::vector<double const *> const &parameters, 
 	   bool give_log) const;
   double p(double q, std::vector<double const *> const &parameters, bool lower,
 	   bool give_log) const;
@@ -25,6 +28,10 @@ class DNegBin : public RScalarDist {
    * Checks that p lies in the interval (0,1) and r > 0
    */
   bool checkParameterValue(std::vector<double const *> const &parameters) const;
+  double KL(std::vector<double const *> const &par1,
+	    std::vector<double const *> const &par2) const;
 };
 
+}
+
 #endif /* DNEGBIN_H_ */
