@@ -3,6 +3,8 @@
 
 #include "RScalarDist.h"
 
+namespace bugs {
+
 /**
  * <pre>
  * x ~ dnorm(mu, tau)
@@ -14,7 +16,8 @@ class DNorm : public RScalarDist {
  public:
   DNorm();
 
-  double d(double x, std::vector<double const *> const &parameters, 
+  double d(double x, PDFType type,
+	   std::vector<double const *> const &parameters, 
 	   bool give_log) const;
   double p(double q, std::vector<double const *> const &parameters, bool lower,
 	   bool give_log) const;
@@ -33,6 +36,10 @@ class DNorm : public RScalarDist {
   double randomSample(std::vector<double const *> const &par,
 		      double const *lower, double const *upper,
 		      RNG *rng) const;
+  double KL(std::vector<double const *> const &par0,
+	    std::vector<double const *> const &par1) const;
 };
 
+}
+
 #endif /* DNORM_H_ */
