@@ -3,6 +3,8 @@
 
 #include "RScalarDist.h"
 
+namespace bugs {
+
 /**
  * <pre>
  * x ~ dpar(alpha, c);
@@ -14,7 +16,8 @@ class DPar : public RScalarDist {
  public:
   DPar();
 
-  double d(double x, std::vector<double const *> const &parameters, bool give_log) const;
+  double d(double x, PDFType type,
+	   std::vector<double const *> const &parameters, bool give_log) const;
   double p(double q, std::vector<double const *> const &parameters, bool lower,
 	   bool give_log) const;
   double q(double p, std::vector<double const *> const &parameters, bool lower,
@@ -29,4 +32,6 @@ class DPar : public RScalarDist {
   bool isSupportFixed(std::vector<bool> const &fixmask) const;
 };
 
+}
+
 #endif /* DPAR_H_ */
