@@ -3,6 +3,8 @@
 
 #include "RScalarDist.h"
 
+namespace bugs {
+
 /**
  * <pre>
  * r ~ dpois(lambda)
@@ -14,7 +16,8 @@ class DPois : public RScalarDist {
  public:
   DPois();
 
-  double d(double x, std::vector<double const *> const &parameters, 
+  double d(double x, PDFType type,
+	   std::vector<double const *> const &parameters, 
 	   bool give_log) const;
   double p(double q, std::vector<double const *> const &parameters, bool lower,
 	   bool give_log) const;
@@ -25,6 +28,10 @@ class DPois : public RScalarDist {
    * Checks that lambda > 0
    */
   bool checkParameterValue(std::vector<double const *> const &parameters) const;
+  double KL(std::vector<double const *> const &par1,
+	    std::vector<double const *> const &par2) const;
 };
 
+}
+
 #endif /* DPOIS_H_ */
