@@ -5,6 +5,7 @@
 
 using std::vector;
 using std::asin;
+using std::string;
 
 namespace bugs {
 
@@ -12,6 +13,11 @@ namespace bugs {
 	: ScalarFunction ("arcsin", 1)
     {
     }
+
+    string ArcSin::alias() const
+    {
+	return "asin";
+    }
     
     double ArcSin::evaluate(vector<double const *> const &args) const
     {
