@@ -5,6 +5,7 @@
 
 using std::vector;
 using std::atan;
+using std::string;
 
 namespace bugs {
 
@@ -12,6 +13,11 @@ namespace bugs {
 	: ScalarFunction ("arctan", 1)
     {
     }
+
+    string ArcTan::alias() const
+    {
+	return "atan";
+    }
     
     double ArcTan::evaluate(vector<double const *> const &args) const
     {
