@@ -5,6 +5,7 @@
 
 using std::vector;
 using std::log;
+using std::string;
 
 namespace bugs {
 
@@ -13,6 +14,11 @@ namespace bugs {
     {
     }
 
+    string ArcTanh::alias() const
+    {
+	return "atanh";
+    }
+
     double ArcTanh::evaluate(vector<double const *> const &args) const
     {
 	double x = *args[0];
