@@ -18,7 +18,7 @@ namespace bugs {
 	return fabs(*args[0] - *args[1]) < 16 *DBL_EPSILON;
     }
 
-    bool Equals::isDiscreteValued(std::vector<bool> const &mask) const
+    bool Equals::isDiscreteValued(vector<bool> const &mask) const
     {
 	return true;
     }
