@@ -10,13 +10,13 @@ using std::log;
 namespace bugs {
 
     Exp::Exp ()
-	: InverseLinkFunc ("exp", "log")
+	: LinkFunction ("exp", "log")
     {
     }
 
-    double Exp::evaluateScalar(vector<double const *> const &args) const
+    double Exp::inverseLink(double eta) const
     {
-	return exp(*args[0]);
+	return exp(eta);
     }
 
     double Exp::link(double mu) const
