@@ -9,14 +9,13 @@ using std::exp;
 
 namespace bugs {
 
-    ICLogLog::ICLogLog(): InverseLinkFunc("icloglog", "cloglog")
+    ICLogLog::ICLogLog(): LinkFunction("icloglog", "cloglog")
     {
     }
 
-    double
-    ICLogLog::evaluateScalar(vector <double const *> const &args) const
+    double ICLogLog::inverseLink(double eta) const
     {
-	return 1 - exp(-exp(*args[0]));
+	return 1 - exp(-exp(eta));
     }
 
     double ICLogLog::link(double mu) const
