@@ -1,7 +1,7 @@
 #ifndef FUNC_ICLOGLOG_H_
 #define FUNC_ICLOGLOG_H_
 
-#include <function/InverseLinkFunc.h>
+#include <function/LinkFunction.h>
 
 namespace bugs {
 
@@ -13,11 +13,11 @@ namespace bugs {
      * y <- icloglog(a + b*x)
      * </pre>
      */
-    class ICLogLog : public InverseLinkFunc
+    class ICLogLog : public LinkFunction
     {
     public:
 	ICLogLog ();
-	double evaluateScalar(std::vector<double const *> const &args) const;
+	double inverseLink(double eta) const;
 	double link(double mu) const;
 	double grad(double eta) const;
     };
