@@ -1,7 +1,7 @@
 #ifndef FUNC_ILOGIT_H_
 #define FUNC_ILOGIT_H_
 
-#include <function/InverseLinkFunc.h>
+#include <function/LinkFunction.h>
 
 namespace bugs {
 
@@ -14,11 +14,11 @@ namespace bugs {
      * y = 1/(1 + exp(-a - b*x))
      * </pre>
      */
-    class ILogit:public InverseLinkFunc
+    class ILogit:public LinkFunction
     {
     public:
 	ILogit ();
-	double evaluateScalar(std::vector <double const *> const &args) const;
+	double inverseLink(double eta) const;
 	double link(double mu) const;
 	double grad(double eta) const;
     };
