@@ -8,17 +8,16 @@ using std::vector;
 
 namespace bugs {
 
-    InterpLin::InterpLin() : Function("interp.lin", 3)
+    InterpLin::InterpLin() : VectorFunction("interp.lin", 3)
     {}
     
     void InterpLin::evaluate(double *value, vector<double const *> const &args,
-			     vector<unsigned int> const &lengths,
-			     vector<vector<unsigned int> > const &dims) const
+			     vector<unsigned int> const &lengths) const
     {
 	double const *x = args[1];
 	double const *y = args[2];
 	double xnew = args[0][0];
-	unsigned int N = dims[1][0];
+	unsigned int N = lengths[1];
     
 	if (xnew < x[0])
 	    value[0] = y[0];
@@ -43,19 +42,15 @@ namespace bugs {
 	}
     }
 
-    bool InterpLin::checkParameterDim(vector<vector<unsigned int> > const &dims)
+    bool InterpLin::checkParameterLength(vector<unsigned int> const &lengths)
 	const
     {
-	return (isScalar(dims[0]) && isVector(dims[1]) && isVector(dims[2]) &&
-		dims[1][0] == dims[2][0]);
-    
+	return (lengths[0] == 1) && (lengths[1] == lengths[2]);
     }
 
     bool 
     InterpLin::checkParameterValue(vector <double const *> const &args,
-				   vector <unsigned int> const &lengths,
-				   vector<vector<unsigned int> > const &dims) 
-	const
+				   vector <unsigned int> const &lengths) const
     {
         unsigned int N = lengths[1];
 	for (unsigned int i = 1; i < N; ++i) {
