@@ -21,7 +21,7 @@ namespace bugs {
     bool 
     Inverse::checkParameterDim (vector<vector<unsigned int> > const &dims) const
     {
-	return isSquareMatrix(dims[0]);
+	return isSquareMatrix(dims[0]) || isScalar(dims[0]);
     }
 
     bool 
