@@ -1,7 +1,7 @@
 #ifndef FUNC_LOG_H_
 #define FUNC_LOG_H_
 
-#include <function/ScalarFunc.h>
+#include <function/ScalarFunction.h>
 
 namespace bugs {
 
@@ -13,11 +13,11 @@ namespace bugs {
      * y = log(x) for x > 0
      * </pre>
      */
-    class Log : public ScalarFunc
+    class Log : public ScalarFunction
     {
     public:
 	Log ();
-	double evaluateScalar(std::vector<double const *> const &args) const;
+	double evaluate(std::vector<double const *> const &args) const;
 	bool checkScalarValue(std::vector<double const *> const &args) const;
     };
 
