@@ -1,7 +1,7 @@
 #ifndef FUNC_LOGGAM_H_
 #define FUNC_LOGGAM_H_
 
-#include <function/ScalarFunc.h>
+#include <function/ScalarFunction.h>
 
 namespace bugs {
 
@@ -12,11 +12,11 @@ namespace bugs {
      * y = log(gamma(x)) for x > 0
      * </pre>
      */
-    class LogGam:public ScalarFunc
+    class LogGam:public ScalarFunction
     {
     public:
 	LogGam ();
-	double evaluateScalar(std::vector<double const *> const &args) const;
+	double evaluate(std::vector<double const *> const &args) const;
 	bool checkScalarValue(std::vector<double const *> const &args) const;
     };
 
