@@ -1,7 +1,7 @@
 #ifndef FUNC_MAX_H_
 #define FUNC_MAX_H_
 
-#include <function/Function.h>
+#include <function/VectorFunction.h>
 
 namespace bugs {
     
@@ -9,16 +9,13 @@ namespace bugs {
      * @short Maximum element of a vector
      * @see Min
      */
-    class Max: public Function
+    class Max: public VectorFunction
     {
     public:
 	Max ();
 	void evaluate(double *x, std::vector <double const *> const &args,
-		      std::vector<unsigned int> const &lengths,
-		      std::vector<std::vector<unsigned int> > const &dims) 
-	    const;
-	bool checkParameterDim (std::vector<std::vector<unsigned int> > const &dims)
-	    const;
+		      std::vector<unsigned int> const &lengths) const;
+	bool checkParameterLength (std::vector<unsigned int> const &len) const;
 	/** Returns true if all arguments are true */
 	bool isDiscreteValued(std::vector<bool> const &mask) const;
     };
