@@ -6,13 +6,12 @@ using std::vector;
 namespace bugs {
 
     Mean::Mean ()
-	: Function ("mean", 1)
+	: VectorFunction ("mean", 1)
     {
     }
 
     void Mean::evaluate (double *x, vector<double const*> const &args,
-			 vector<unsigned int> const &lengths,
-			 vector<vector<unsigned int> > const &dims) const
+			 vector<unsigned int> const &lengths) const
     {
 	double svalue = 0;
 	for (unsigned int i = 0; i < lengths[0]; i++) {
@@ -22,23 +21,14 @@ namespace bugs {
 	*x = svalue;
     }
 
-    bool 
-    Mean::checkParameterDim (vector<vector<unsigned int> > const &dims) const
+    bool Mean::checkParameterLength (vector<unsigned int> const &lengths) const
     {
 	return true;
     }
 
-    bool 
-    Mean::isLinear(vector<bool> const &mask, vector<bool> const &fix) const
+    bool Mean::isScale(vector<bool> const &mask, vector<bool> const &fix) const
     {
 	return true;
     }
-
-    bool 
-    Mean::isScale(unsigned int index, vector<bool> const &fix) const
-    {
-	return true;
-    }
-
 }
 
