@@ -1,7 +1,7 @@
 #ifndef FUNC_ROUND_H_
 #define FUNC_ROUND_H_
 
-#include <function/ScalarFunc.h>
+#include <function/ScalarFunction.h>
 
 namespace bugs {
 
@@ -11,11 +11,11 @@ namespace bugs {
      * y <- round(x)
      * </pre>
      */
-    class Round : public ScalarFunc
+    class Round : public ScalarFunction
     {
     public:
 	Round ();
-	double evaluateScalar(std::vector<double const *> const &args) const;
+	double evaluate(std::vector<double const *> const &args) const;
 	bool isDiscreteValued(std::vector<bool> const &mask) const;
     };
 }
