@@ -1,7 +1,7 @@
 #ifndef FUNC_SD_H_
 #define FUNC_SD_H_
 
-#include <function/Function.h>
+#include <function/VectorFunction.h>
 
 namespace bugs {
 
@@ -14,16 +14,13 @@ namespace bugs {
      * y <- sd(x[])
      * </pre>
      */
-    class SD : public Function
+    class SD : public VectorFunction
     {
     public:
 	SD ();
 	void evaluate (double *x, std::vector<double const *> const &args,
-		       std::vector<unsigned int> const &lengths,
-		       std::vector<std::vector<unsigned int> > const &dims) 
-	    const;
-	bool checkParameterDim (std::vector<std::vector<unsigned int> > const &dims) 
-	    const;
+		       std::vector<unsigned int> const &lengths) const;
+	bool checkParameterLength (std::vector<unsigned int> const &len) const;
     };
 }
 
