@@ -9,11 +9,11 @@ using std::floor;
 
 namespace bugs {
 
-    Trunc::Trunc ():ScalarFunc ("trunc", 1)
+    Trunc::Trunc ():ScalarFunction ("trunc", 1)
     {
     }
 
-    double Trunc::evaluateScalar(vector<double const *> const &args) const
+    double Trunc::evaluate(vector<double const *> const &args) const
     {
 	/* The C99 trunc function does not exist in the current C++ standard. */
 	return args[0][0] >= 0 ? floor(args[0][0]) : -floor(-args[0][0]);
