@@ -5,6 +5,8 @@
 
 class StochasticNode;
 
+namespace bugs {
+
 /**
  * Update Method for censored real-valued distributions.
  */
@@ -17,4 +19,6 @@ public:
     std::string name() const;
 };
 
+}
+
 #endif /* CENSORED_H_ */
