@@ -3,6 +3,8 @@
 
 #include "ConjugateMethod.h"
 
+namespace bugs {
+
 /**
  * @short Conjugate sampler for the beta distribution
  *
@@ -20,4 +22,6 @@ public:
     std::string name() const;
 };
 
+}
+
 #endif /* CONJUGATE_BETA_H_ */
