@@ -3,6 +3,8 @@
 
 #include "ConjugateMethod.h"
 
+namespace bugs {
+
 class ConjugateGamma : public ConjugateMethod {
     double *_coef;
 public:
@@ -13,4 +15,6 @@ public:
     std::string name() const;
 };
 
+}
+
 #endif /* CONJUGATE_GAMMA_H_ */
