@@ -3,6 +3,8 @@
 
 #include "ConjugateMethod.h"
 
+namespace bugs {
+
 /**
  * Conjugate sampler for multivariate normal distribution
  *
@@ -27,4 +29,6 @@ class ConjugateMNormal : public ConjugateMethod {
   std::string name() const;
 };
 
+}
+
 #endif /* CONJUGATE_M_NORMAL_H_ */
