@@ -9,6 +9,8 @@ class RNG;
 class Graph;
 class StochasticNode;
 
+namespace bugs {
+
 enum ConjugateDist {
     BERN, BETA, BIN, CAT, CHISQ, DEXP, DIRCH, EXP, GAMMA,
     LNORM, LOGIS, MNORM, MULTI, NEGBIN, NORM, PAR, POIS,
@@ -35,5 +37,7 @@ public:
     virtual std::string name() const = 0;
 };
 
+}
+
 #endif /* CONJUGATE_METHOD_H_ */
 
