@@ -6,6 +6,8 @@
 using std::vector;
 using std::string;
 
+namespace bugs {
+
 ConjugateSampler::ConjugateSampler(GraphView *gv, ConjugateMethod *method)
     : Sampler(gv), _method(method), _nchain(nchain(gv))
 {
@@ -28,7 +30,11 @@ bool ConjugateSampler::isAdaptive() const
     return false;
 }
 
-bool ConjugateSampler::adaptOff()
+void ConjugateSampler::adaptOff()
+{
+}
+
+bool ConjugateSampler::checkAdaptation() const
 {
     return true;
 }
@@ -37,3 +43,5 @@ string ConjugateSampler::name() const
 {
     return _method->name();
 }
+
+}
