@@ -3,6 +3,8 @@
 
 #include "ConjugateMethod.h"
 
+namespace bugs {
+
 /**
  * Conjugate method for the Wishart distribution
  *
@@ -19,4 +21,6 @@ public:
     std::string name() const;
 };
 
+}
+
 #endif /* CONJUGATE_WISHART_H_ */
