@@ -8,16 +8,16 @@
 #include "DMultiDSum.h"
 
 #include <cmath>
-#include <stdexcept>
 
 using std::vector;
 using std::fabs;
-using std::logic_error;
 using std::string;
 
 //Initial step size
 #define STEP 1
 
+namespace bugs {
+
 DMultiDSum::DMultiDSum(GraphView const *gv, unsigned int chain)
     : RWDSum(gv, chain, STEP)
 {
@@ -62,3 +62,4 @@ string DMultiDSum::name() const
     return "DMultiDSum";
 }
 
+}
