@@ -5,6 +5,8 @@
 
 class StochasticNode;
 
+namespace bugs {
+
 /**
  * @short Sample parents of dsum nodes
  */
@@ -17,4 +19,6 @@ public:
     std::string name() const;
 };
 
+}
+
 #endif /* DMULTI_DSUM_H_ */
