@@ -3,6 +3,8 @@
 
 #include <sampler/SamplerFactory.h>
 
+namespace bugs {
+
 /**
  * @short Factory object for discrete sum samplers
  */
@@ -16,4 +18,6 @@ public:
     std::string name() const;
 };
 
+}
+
 #endif /* DSUM_FACTORY_H_ */
