@@ -4,7 +4,7 @@
 #include <sampler/RWMetropolis.h>
 #include <sampler/GraphView.h>
 
-//class GraphView;
+namespace bugs {
 
 class DirchMetropolis : public RWMetropolis
 {
@@ -21,4 +21,6 @@ public:
     std::string name() const;
 };
 
+}
+
 #endif /* DIRICHLET_METROPOLIS_H_ */
