@@ -5,6 +5,8 @@
 
 #include <sampler/SingletonFactory.h>
 
+namespace bugs {
+
 /**
  * @short Factory object for multivariate normal samplers
  */
@@ -16,4 +18,6 @@ public:
     std::string name() const;
 };
 
+}
+
 #endif /* DIRICHLET_FACTORY_H_ */
