@@ -8,20 +8,14 @@
 #include "DiscreteDSum.h"
 
 #include <cmath>
-#include <stdexcept>
 
 using std::vector;
 using std::fabs;
-using std::logic_error;
 using std::string;
 
 //Initial step size
 #define STEP 1
 
-DiscreteDSum::DiscreteDSum(GraphView const *gv, unsigned int chain)
-    : RWDSum(gv, chain, STEP)
-{
-}
 
 //Pick a random integer between 0 and n - 1
 static int pick(int n, RNG *rng)
@@ -32,6 +26,13 @@ static int pick(int n, RNG *rng)
     return i - 1;
 }
 
+namespace bugs {
+
+DiscreteDSum::DiscreteDSum(GraphView const *gv, unsigned int chain)
+    : RWDSum(gv, chain, STEP)
+{
+}
+
 void DiscreteDSum::step(vector<double> &value, 
 			unsigned int nrow, unsigned int ncol,
 			double s, RNG *rng) const
@@ -56,3 +57,4 @@ string DiscreteDSum::name() const
     return "DiscreteDSum";
 }
 
+}
