@@ -10,14 +10,12 @@
 #include <rng/RNG.h>
 
 #include <cmath>
-#include <stdexcept>
 #include <algorithm>
 
 #define N_REFRESH 100
 
 using std::vector;
 using std::copy;
-using std::logic_error;
 using std::exp;
 using std::sqrt;
 using std::min;
@@ -34,6 +32,7 @@ static vector<double> initValue(GraphView const *gv, unsigned int chain)
     return ivalue;
 }
 
+namespace bugs {
 
 MNormMetropolis::MNormMetropolis(GraphView const *gv, unsigned int chain)
     : Metropolis(initValue(gv, chain)),
@@ -176,3 +175,5 @@ void MNormMetropolis::setValue(vector<double> const &value)
 {
     _gv->setValue(value, _chain);
 }
+
+}
