@@ -5,6 +5,8 @@
 
 class GraphView;
 
+namespace bugs {
+
 class MNormMetropolis : public Metropolis
 {
     GraphView const *_gv;
@@ -29,4 +31,6 @@ public:
     void setValue(std::vector<double> const &value);
 };
 
+}
+
 #endif /* MNORM_METROPOLIS_H_ */
