@@ -8,6 +8,8 @@
 class StochasticNode;
 class GraphView;
 
+namespace bugs {
+
 /**
  * @short Sample parents of dsum nodes
  */
@@ -20,4 +22,6 @@ public:
     std::string name() const;
 };
 
+}
+
 #endif /* REAL_DSUM_H_ */
