@@ -5,6 +5,8 @@
 
 class Node;
 
+namespace bugs {
+
 class TruncatedGamma : public ConjugateMethod {
     double _shape;
     Node const *_parent;
@@ -16,4 +18,6 @@ public:
     std::string name() const;
 };
 
+}
+
 #endif /* TRUNCATED_GAMMA_H_ */
