@@ -13,10 +13,18 @@ using std::log;
 namespace dic {
 
     double KLBern::divergence(vector<double const *> const &par0,
-			     vector<double const *> const &par1) const
+			      vector<double const *> const &par1) const
     {
-	return (PROB0 - PROB1) * 
-	    (log (PROB0/(1 - PROB0)) - log(PROB1/(1 - PROB1)));
+	if (PROB0 == 0) {
+	    return - log(1 - PROB1);
+	}
+	else if (PROB0 == 1) {
+	    return - log(PROB1);
+	}
+	else {
+	    return (PROB0 * (log(PROB0) - log(PROB1)) +
+		    (1 - PROB0) * (log(1 - PROB0) - log(1 - PROB1)));
+	}
     }
 
 }
