@@ -14,7 +14,8 @@ namespace dic {
     double KLPois::divergence(vector<double const *> const &par0,
 			      vector<double const *> const &par1) const
     {
-	return  (lambda0 - lambda1) * log(lambda0/lambda1);
+	
+	return  lambda0 * log(lambda0/lambda1) + (lambda1 - lambda0);
     }
     
 }
