@@ -9,7 +9,8 @@ namespace dic {
     {
       public:
 	Monitor *getMonitor(std::string const &name, Range const &range,
-			    BUGSModel *model, std::string const &type);
+			    BUGSModel *model, std::string const &type,
+			    std::string &msg);
 	std::string name() const;
     };
     
